@@ -26,7 +26,7 @@ test_instantiation (void)
 
   stream = g_object_new (WOCKY_TYPE_TEST_STREAM, NULL);
   connection = wocky_xmpp_connection_new (stream->stream0);
-  session = wocky_session_new (connection, "example.com");
+  session = wocky_session_new_with_connection (connection, "example.com");
 
   roster = wocky_roster_new (session);
 
@@ -630,7 +630,7 @@ check_edit_roster_stanza (WockyStanza *stanza,
     }
 
   g_assert (g_hash_table_size (expected_groups) == 0);
-  g_hash_table_destroy (expected_groups);
+  g_hash_table_unref (expected_groups);
 }
 
 static void
