@@ -493,8 +493,8 @@ groups_equal (const gchar * const * groups_a,
         result = FALSE;
     }
 
-  g_ptr_array_free (arr_a, TRUE);
-  g_ptr_array_free (arr_b, TRUE);
+  g_ptr_array_unref (arr_a);
+  g_ptr_array_unref (arr_b);
   return result;
 }
 
