@@ -372,8 +372,7 @@ starttls_recv_cb (GObject *source,
   DEBUG ("Received STARTTLS response");
   node = wocky_stanza_get_top_node (stanza);
 
-  if (wocky_strdiff (node->name, "proceed") ||
-      wocky_strdiff (wocky_node_get_ns (node), WOCKY_XMPP_NS_TLS))
+  if (!wocky_node_matches (node, "proceed", WOCKY_XMPP_NS_TLS))
     {
       report_error_in_idle (self, WOCKY_CONNECTOR_ERROR_TLS_REFUSED,
           "%s", "STARTTLS refused by the server");
