@@ -309,7 +309,7 @@ gabble_ft_manager_channels_created (GabbleFtManager *self, GList *channels)
 
   tp_channel_manager_emit_new_channels (self, new_channels);
 
-  g_hash_table_destroy (new_channels);
+  g_hash_table_unref (new_channels);
 }
 
 static void
@@ -663,7 +663,7 @@ gabble_ft_manager_type_foreach_channel_class (GType type,
   func (type, table, file_transfer_channel_allowed_properties_with_both_metadata_props + 1,
       user_data);
 
-  g_hash_table_destroy (table);
+  g_hash_table_unref (table);
 }
 
 static LmMessageNode *
@@ -974,7 +974,7 @@ add_file_transfer_channel_class (GPtrArray *arr,
       1, allowed_properties,
       G_MAXUINT);
 
-  g_hash_table_destroy (fixed_properties);
+  g_hash_table_unref (fixed_properties);
 
   g_ptr_array_add (arr, g_value_get_boxed (&monster));
 }
