@@ -23,8 +23,10 @@
 
 #include <string.h>
 #include <telepathy-glib/channel-manager.h>
+#include <wocky/wocky-utils.h>
+#include <wocky/wocky-xep-0115-capabilities.h>
 
-#include "capabilities.h"
+#include "gabble/capabilities.h"
 #include "conn-presence.h"
 #include "presence-cache.h"
 #include "namespaces.h"
@@ -35,7 +37,12 @@
 
 #include "debug.h"
 
-G_DEFINE_TYPE (GabblePresence, gabble_presence, G_TYPE_OBJECT);
+static void xep_0115_capabilities_iface_init (gpointer, gpointer);
+
+G_DEFINE_TYPE_WITH_CODE (GabblePresence, gabble_presence, G_TYPE_OBJECT,
+    G_IMPLEMENT_INTERFACE (WOCKY_TYPE_XEP_0115_CAPABILITIES,
+        xep_0115_capabilities_iface_init);
+)
 
 typedef struct _Resource Resource;
 
@@ -43,6 +50,7 @@ struct _Resource {
     gchar *name;
     guint client_type;
     GabbleCapabilitySet *cap_set;
+    GPtrArray *data_forms;
     guint caps_serial;
     GabblePresenceId status;
     gchar *status_message;
@@ -57,6 +65,9 @@ struct _GabblePresencePrivate {
     /* The aggregated caps of all the contacts' resources. */
     GabbleCapabilitySet *cap_set;
 
+    /* The aggregated data forms of all the contacts' resources */
+    GPtrArray *data_forms;
+
     gchar *no_resource_status_message;
     GSList *resources;
     guint olpc_views;
@@ -71,6 +82,8 @@ _resource_new (gchar *name)
   new->name = name;
   new->client_type = 0;
   new->cap_set = gabble_capability_set_new ();
+  new->data_forms = g_ptr_array_new_with_free_func (
+      (GDestroyNotify) g_object_unref);
   new->status = GABBLE_PRESENCE_OFFLINE;
   new->status_message = NULL;
   new->priority = 0;
@@ -86,6 +99,7 @@ _resource_free (Resource *resource)
   g_free (resource->name);
   g_free (resource->status_message);
   gabble_capability_set_free (resource->cap_set);
+  g_ptr_array_unref (resource->data_forms);
 
   g_slice_free (Resource, resource);
 }
@@ -102,6 +116,7 @@ gabble_presence_finalize (GObject *object)
 
   g_slist_free (priv->resources);
   gabble_capability_set_free (priv->cap_set);
+  g_ptr_array_unref (priv->data_forms);
 
   g_free (presence->nickname);
   g_free (presence->avatar_sha1);
@@ -127,7 +142,11 @@ gabble_presence_init (GabblePresence *self)
 
   priv = self->priv;
   priv->cap_set = gabble_capability_set_new ();
+  priv->data_forms = g_ptr_array_new_with_free_func (
+      (GDestroyNotify) g_object_unref);
   priv->resources = NULL;
+
+  self->status = GABBLE_PRESENCE_UNKNOWN;
 }
 
 GabblePresence *
@@ -195,6 +214,13 @@ gabble_presence_peek_caps (GabblePresence *presence)
   return presence->priv->cap_set;
 }
 
+GPtrArray *
+gabble_presence_peek_data_forms (GabblePresence *presence)
+{
+  g_return_val_if_fail (presence != NULL, NULL);
+  return presence->priv->data_forms;
+}
+
 gboolean
 gabble_presence_has_resources (GabblePresence *self)
 {
@@ -263,10 +289,22 @@ gabble_presence_resource_has_caps (GabblePresence *presence,
   return FALSE;
 }
 
+static void
+extend_and_dup (GPtrArray *target,
+    GPtrArray *source)
+{
+  if (source == NULL)
+    return;
+
+  g_ptr_array_foreach (source, (GFunc) g_object_ref, NULL);
+  tp_g_ptr_array_extend (target, source);
+}
+
 void
 gabble_presence_set_capabilities (GabblePresence *presence,
                                   const gchar *resource,
                                   const GabbleCapabilitySet *cap_set,
+                                  const GPtrArray *data_forms,
                                   guint serial)
 {
   GabblePresencePrivate *priv = presence->priv;
@@ -285,11 +323,13 @@ gabble_presence_set_capabilities (GabblePresence *presence,
     }
 
   gabble_capability_set_clear (priv->cap_set);
+  g_ptr_array_set_size (priv->data_forms, 0);
 
   if (resource == NULL)
     {
       DEBUG ("Setting capabilities for bare JID");
       gabble_capability_set_update (priv->cap_set, cap_set);
+      extend_and_dup (priv->data_forms, (GPtrArray *) data_forms);
       return;
     }
 
@@ -312,6 +352,7 @@ gabble_presence_set_capabilities (GabblePresence *presence,
                 tmp->caps_serial);
               tmp->caps_serial = serial;
               gabble_capability_set_clear (tmp->cap_set);
+              g_ptr_array_set_size (tmp->data_forms, 0);
             }
 
           if (serial >= tmp->caps_serial)
@@ -319,11 +360,19 @@ gabble_presence_set_capabilities (GabblePresence *presence,
               DEBUG ("updating caps for resource %s", resource);
 
               gabble_capability_set_update (tmp->cap_set, cap_set);
+
+              /* TODO: deal with duplicates */
+              extend_and_dup (tmp->data_forms, (GPtrArray *) data_forms);
             }
         }
 
       gabble_capability_set_update (priv->cap_set, tmp->cap_set);
+
+      /* TODO: deal with duplicates */
+      extend_and_dup (priv->data_forms, tmp->data_forms);
     }
+
+  g_signal_emit_by_name (presence, "capabilities-changed");
 }
 
 static Resource *
@@ -636,13 +685,19 @@ gabble_presence_dump (GabblePresence *presence)
   GString *ret = g_string_new ("");
   gchar *tmp;
   GabblePresencePrivate *priv = presence->priv;
+  const gchar *presence_name = wocky_enum_to_nick (GABBLE_TYPE_PRESENCE_ID,
+      presence->status);
+
+  if (presence_name == NULL)
+    presence_name = "plugin-specific, not an element of GabblePresenceId";
 
   g_string_append_printf (ret,
     "nickname: %s\n"
-    "accumulated status: %d\n"
+    "accumulated status: %d (%s)\n"
     "accumulated status msg: %s\n"
     "kept while unavailable: %d\n",
-    presence->nickname, presence->status,
+    presence->nickname,
+    presence->status, presence_name,
     presence->status_message,
     presence->keep_unavailable);
 
@@ -846,3 +901,20 @@ gabble_presence_get_client_types_array (GabblePresence *presence,
 
   return (gchar **) g_ptr_array_free (array, FALSE);
 }
+
+static const GPtrArray *
+gabble_presence_get_data_forms (WockyXep0115Capabilities *caps)
+{
+  GabblePresence *presence = GABBLE_PRESENCE (caps);
+
+  return presence->priv->data_forms;
+}
+
+static void
+xep_0115_capabilities_iface_init (gpointer g_iface,
+    gpointer iface_data)
+{
+  WockyXep0115CapabilitiesInterface *iface = g_iface;
+
+  iface->get_data_forms = gabble_presence_get_data_forms;
+}
