@@ -139,6 +139,7 @@ CONN_IFACE_CONTACT_GROUPS = CONN + '.Interface.ContactGroups'
 CONN_IFACE_CLIENT_TYPES = CONN + '.Interface.ClientTypes'
 CONN_IFACE_POWER_SAVING = CONN + '.Interface.PowerSaving'
 CONN_IFACE_CONTACT_BLOCKING = CONN + '.Interface.ContactBlocking'
+CONN_IFACE_ADDRESSING = CONN + '.Interface.Addressing1'
 
 ATTR_CONTACT_CAPABILITIES = CONN_IFACE_CONTACT_CAPS + '/capabilities'
 
@@ -416,6 +417,8 @@ MT_DELIVERY_REPORT = 4
 
 PROTOCOL = 'org.freedesktop.Telepathy.Protocol'
 PROTOCOL_IFACE_PRESENCES = PROTOCOL + '.Interface.Presence'
+PROTOCOL_IFACE_ADDRESSING = PROTOCOL + '.Interface.Addressing'
+
 PARAM_REQUIRED = 1
 PARAM_REGISTER = 2
 PARAM_HAS_DEFAULT = 4
