@@ -394,7 +394,7 @@ class SendFileTest(FileTransferTest):
                  cs.TARGET_HANDLE_TYPE: cs.HT_CONTACT},
                 [cs.FT_CONTENT_HASH_TYPE, cs.TARGET_HANDLE, cs.TARGET_ID, cs.FT_CONTENT_TYPE,
                  cs.FT_FILENAME, cs.FT_SIZE, cs.FT_CONTENT_HASH, cs.FT_DESCRIPTION, cs.FT_DATE,
-                 cs.FT_URI]
+                 cs.FT_URI, cs.FT_SERVICE_NAME, cs.FT_METADATA]
              ) in properties.get('RequestableChannelClasses'),\
                      properties['RequestableChannelClasses']
 
@@ -404,14 +404,12 @@ class SendFileTest(FileTransferTest):
                  cs.FT_CONTENT_HASH_TYPE: cs.FILE_HASH_TYPE_MD5},
                 [cs.TARGET_HANDLE, cs.TARGET_ID, cs.FT_CONTENT_TYPE, cs.FT_FILENAME,
                  cs.FT_SIZE, cs.FT_CONTENT_HASH, cs.FT_DESCRIPTION, cs.FT_DATE,
-                 cs.FT_URI]
+                 cs.FT_URI, cs.FT_SERVICE_NAME, cs.FT_METADATA]
              ) in properties.get('RequestableChannelClasses'),\
                      properties['RequestableChannelClasses']
 
     def request_ft_channel(self):
-        requests_iface = dbus.Interface(self.conn, cs.CONN_IFACE_REQUESTS)
-
-        self.ft_path, props = requests_iface.CreateChannel({
+        self.ft_path, props = self.conn.Requests.CreateChannel({
             cs.CHANNEL_TYPE: cs.CHANNEL_TYPE_FILE_TRANSFER,
             cs.TARGET_HANDLE_TYPE: cs.HT_CONTACT,
             cs.TARGET_HANDLE: self.handle,
